@@ -11,7 +11,7 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: common.py,v 1.17 2004/08/27 18:14:03 tkawa Exp $
+# $Id: common.py,v 1.22 2004/09/27 16:09:22 atzm Exp $
 #
 
 import os, sys
@@ -19,7 +19,7 @@ import gtk
 
 # common defines
 APP = 'GBottler'
-VER = '0.1.0'
+VER = '0.1.2'
 
 VOTE  = "Vote"
 AGREE = "Agree"
@@ -38,6 +38,10 @@ POS_PREV  = 'pos_prev'
 POS_FIRST = 'pos_leftmost'
 POS_END   = 'pos_rightmost'
 
+STATE_BOTTLE_PLAYING  = gtk.STOCK_REFRESH
+STATE_BOTTLE_RESERVED = gtk.STOCK_APPLY
+STATE_BOTTLE_NONE     = ''
+
 DL_SUFFIX_PATTERNS = {
 	'png': '[Pp][Nn][Gg]',
 	'mpg': '[Mm][Nn][Gg]',
@@ -115,7 +119,7 @@ def get_icon_box(stock, label, size=gtk.ICON_SIZE_MENU):
 	return h
 
 def get_hbox_with_label_button(stock, label, size=gtk.ICON_SIZE_MENU,
-							  relief=gtk.RELIEF_NONE):
+							   relief=gtk.RELIEF_NONE):
 	i = gtk.Image()
 	i.set_from_stock(stock, size)
 	i.show()
@@ -146,7 +150,7 @@ def get_hbox_with_label_button(stock, label, size=gtk.ICON_SIZE_MENU,
 def get_simple_dialog(title, stock, label, parent=None):
 	d = gtk.Dialog(title, parent,
 				   gtk.DIALOG_DESTROY_WITH_PARENT|gtk.DIALOG_MODAL|gtk.DIALOG_NO_SEPARATOR,
-				   (gtk.STOCK_OK, gtk.RESPONSE_ACCEPT))
+				   (gtk.STOCK_OK, gtk.RESPONSE_OK))
 	d.connect("destroy", lambda w: w.destroy)
 	h = get_icon_box(stock, label, gtk.ICON_SIZE_DIALOG)
 	d.vbox.pack_start(h)
@@ -155,8 +159,8 @@ def get_simple_dialog(title, stock, label, parent=None):
 def get_simple_yes_or_no_dialog(title, label, parent=None, stock=gtk.STOCK_DIALOG_QUESTION):
 	d = gtk.Dialog(title, parent,
 				   gtk.DIALOG_DESTROY_WITH_PARENT|gtk.DIALOG_MODAL|gtk.DIALOG_NO_SEPARATOR,
-				   (gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT,
-					gtk.STOCK_OK, gtk.RESPONSE_ACCEPT))
+				   (gtk.STOCK_NO, gtk.RESPONSE_NO,
+					gtk.STOCK_YES, gtk.RESPONSE_YES))
 	d.connect("destroy", lambda w: w.destroy)
 	h = get_icon_box(stock,
 					 label,
@@ -176,7 +180,7 @@ def open_error_dialog(label, parent=None, stock=gtk.STOCK_DIALOG_ERROR):
 def open_simple_entry_dialog(title, label, parent=None, stock=gtk.STOCK_DIALOG_QUESTION):
 	d = gtk.Dialog(title, parent,
 				   gtk.DIALOG_DESTROY_WITH_PARENT|gtk.DIALOG_MODAL|gtk.DIALOG_NO_SEPARATOR,
-				   (gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT, gtk.STOCK_OK, gtk.RESPONSE_ACCEPT))
+				   (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL, gtk.STOCK_OK, gtk.RESPONSE_OK))
 	d.connect("destroy", lambda w: w.destroy)
 	h = get_icon_box(stock, label, gtk.ICON_SIZE_DIALOG)
 	d.vbox.pack_start(h)
@@ -186,7 +190,7 @@ def open_simple_entry_dialog(title, label, parent=None, stock=gtk.STOCK_DIALOG_Q
 	d.show()
 
 	response = d.run()
-	if response == gtk.RESPONSE_ACCEPT:
+	if response == gtk.RESPONSE_OK:
 		result = e.get_text()
 	else:
 		result = ''
@@ -194,3 +198,17 @@ def open_simple_entry_dialog(title, label, parent=None, stock=gtk.STOCK_DIALOG_Q
 	d.destroy()
 	d = None
 	return result
+
+def open_overwrite_check_dialog(parent=None, filename=''):
+	d = get_simple_yes_or_no_dialog(unicode(_("Really?"), 'utf-8'),
+									unicode(_("File already exists."), 'utf-8') + " " + \
+									unicode(_("overwrite?"), 'utf-8') + "\n\n" + \
+									filename + '\n',
+									parent)
+	d.show()
+	res = d.run()
+	d.destroy()
+
+	if not res or res == gtk.RESPONSE_NO:
+		return False
+	return True
