@@ -10,10 +10,10 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: gvwindow.py,v 1.10 2004/07/27 20:04:43 atzm Exp $
+# $Id: gvwindow.py,v 1.14 2004/09/21 06:36:16 atzm Exp $
 #
 
-import gtk
+import gtk, pango
 from viewer.ghostmanager import GhostManager
 from viewer.gviewer import GViewerQueue
 from viewer.viewercommon import SIZE_SURFACE_H, SIZE_SURFACE_V
@@ -33,16 +33,16 @@ class GVWindow:
 		sakura_frame.set_size_request(SIZE_SURFACE_H+5, SIZE_SURFACE_V+5)
 		sakura_frame.show()
 
-		t1 = gtk.TextView()
-		t1.show()
-		t1.set_wrap_mode(gtk.WRAP_CHAR)
-		t1.set_editable(gtk.FALSE)
-		t1.set_cursor_visible(gtk.FALSE)
-		b1 = t1.get_buffer()
+		self.t1 = gtk.TextView()
+		self.t1.show()
+		self.t1.set_wrap_mode(gtk.WRAP_CHAR)
+		self.t1.set_editable(gtk.FALSE)
+		self.t1.set_cursor_visible(gtk.FALSE)
+		b1 = self.t1.get_buffer()
 		sw1 = gtk.ScrolledWindow()
 		sw1.show()
 		sw1.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_ALWAYS)
-		sw1.add(t1)
+		sw1.add(self.t1)
 		f1 = gtk.Frame()
 		f1.show()
 		f1.set_shadow_type(gtk.SHADOW_IN)
@@ -60,16 +60,16 @@ class GVWindow:
 		kero_frame.set_size_request(SIZE_SURFACE_H+5, SIZE_SURFACE_V+5)
 		kero_frame.show()
 
-		t2 = gtk.TextView()
-		t2.show()
-		t2.set_wrap_mode(gtk.WRAP_CHAR)
-		t2.set_editable(gtk.FALSE)
-		t2.set_cursor_visible(gtk.FALSE)
-		b2 = t2.get_buffer()
+		self.t2 = gtk.TextView()
+		self.t2.show()
+		self.t2.set_wrap_mode(gtk.WRAP_CHAR)
+		self.t2.set_editable(gtk.FALSE)
+		self.t2.set_cursor_visible(gtk.FALSE)
+		b2 = self.t2.get_buffer()
 		sw2 = gtk.ScrolledWindow()
 		sw2.show()
 		sw2.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_ALWAYS)
-		sw2.add(t2)
+		sw2.add(self.t2)
 		f2 = gtk.Frame()
 		f2.show()
 		f2.set_shadow_type(gtk.SHADOW_IN)
@@ -124,11 +124,16 @@ class GVWindow:
 		cbutton = gtk.Button(unicode(_('Cancel all'), 'utf-8'))
 		cbutton.show()
 
+		# cancel button
+		closebutton = gtk.Button(unicode(_('Close'), 'utf-8'))
+		closebutton.show()
+
 		# buttons
-		bbox = gtk.HBox()
+		bbox = gtk.HBox(gtk.TRUE)
 		bbox.show()
 		bbox.pack_start(ibutton)
 		bbox.pack_start(cbutton)
+		bbox.pack_start(closebutton)
 
 		# all
 		box = gtk.VBox()
@@ -141,10 +146,10 @@ class GVWindow:
 		# window
 		accel_group = gtk.AccelGroup()
 		self.window = gtk.Window()
+		self.window.add_accel_group(accel_group)
 		self.window.set_title(unicode(_(APP), "utf-8") + ": " + \
 							  unicode(_("GViewer"), "utf-8"))
 		self.window.set_size_request(400+10, SIZE_SURFACE_V * 2 + 160)
-		self.window.add_accel_group(accel_group)
 		self.window.connect('delete-event', self.close)
 		self.window.add(box)
 
@@ -152,7 +157,16 @@ class GVWindow:
 							   [kero_frame, b2, sw2], sc_label, g_label, r_label)
 
 		ibutton.connect('clicked', lambda x: self.gv.cancel())
+		ibutton.add_accelerator("clicked",  accel_group, ord('C'),
+								gtk.gdk.CONTROL_MASK, gtk.ACCEL_VISIBLE)
+
 		cbutton.connect('clicked', lambda x: self.gv.cancel_all())
+		cbutton.add_accelerator("clicked",  accel_group, ord('G'),
+								gtk.gdk.CONTROL_MASK, gtk.ACCEL_VISIBLE)
+
+		closebutton.connect('clicked', lambda x: self.close())
+		closebutton.add_accelerator("clicked",  accel_group, ord('Q'),
+									gtk.gdk.CONTROL_MASK, gtk.ACCEL_VISIBLE)
 
 	def enqueue(self, channel, ifghost, script, sender):
 		ghost = self.ghostmanager.nominate_ghost(ifghost, self.ghost_dir)
@@ -161,6 +175,13 @@ class GVWindow:
 	def get_fmo_ghosts(self):
 		return self.ghostmanager.get_fmo_ghosts()
 
+	def notify_cancel_all(self):
+		self.gv.cancel_all()
+
+	def notify_font_changed(self, genfont):
+		self.t1.modify_font(pango.FontDescription(genfont))
+		self.t2.modify_font(pango.FontDescription(genfont))
+
 	def notify_svg_changed(self):
 		self.ghostmanager.generate_dictionary(self.ghost_text)
 
