@@ -10,7 +10,7 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: prefs.py,v 1.47 2004/06/17 15:58:59 atzm Exp $
+# $Id: prefs.py,v 1.55 2004/09/15 06:09:09 atzm Exp $
 #
 
 import os, sys, re, string
@@ -32,21 +32,17 @@ class PreferenceDialog:
 		self.prefs['auto_clear']    = gtk.CheckButton(unicode(_("Clear editor after send")))
 		self.prefs['sent_log']      = gtk.CheckButton(unicode(_("Logging history of sent script")))
 
-		self.genbox = gtk.VBox()
-		self.genbox.show()
+		genbox = gtk.VBox()
 		for name in ['auto_open_log', 'auto_connect', 'auto_join', 'auto_clear', 'sent_log']:
 			self.prefs[name].set_border_width(5)
-			self.prefs[name].show()
-			self.genbox.pack_start(self.prefs[name], gtk.FALSE, gtk.FALSE, 0)
+			genbox.pack_start(self.prefs[name], gtk.FALSE, gtk.FALSE, 0)
 
-		self.genframe = gtk.Frame(unicode(_("General")))
-		self.genframe.show()
-		self.genframe.set_border_width(5)
-		self.genframe.add(self.genbox)
+		genframe = gtk.Frame(unicode(_("General")))
+		genframe.set_border_width(5)
+		genframe.add(genbox)
 
 # === Create SSTP Frame === #
-		self.sendbox = gtk.VBox()
-		self.sendbox.show()
+		sendbox = gtk.VBox()
 
 		self.prefs['forward'] = gtk.CheckButton(unicode(_("Forward")))
 		self.prefs['accept_all'] = gtk.RadioButton(None, unicode(_("Accept All")))
@@ -54,140 +50,144 @@ class PreferenceDialog:
 													   unicode(_("Forward only listed Ghost")))
 		for name in ['forward', 'accept_all', 'forward_listed']:
 			self.prefs[name].set_border_width(5)
-			self.prefs[name].show()
-			self.sendbox.pack_start(self.prefs[name], gtk.FALSE, gtk.FALSE, 0)
+			sendbox.pack_start(self.prefs[name], gtk.FALSE, gtk.FALSE, 0)
 		self.prefs['forward'].connect('toggled', self.forward_toggled)
 
-		self.sendframe = gtk.Frame(unicode(_("SSTP server")))
-		self.sendframe.show()
-		self.sendframe.set_border_width(5)
-		self.sendframe.add(self.sendbox)
+		sendframe = gtk.Frame(unicode(_("SSTP server")))
+		sendframe.set_border_width(5)
+		sendframe.add(sendbox)
 
 # === Create Initial Script Frame === #
 		self.prefs['initialscript'] = gtk.Entry()
-		self.prefs['initialscript'].show()
 
-		iniscl = gtk.Label(unicode(_('A first | is cursor position'), 'utf-8'))
-		iniscl.show()
+		iniscbox = gtk.VBox()
+		iniscbox.pack_start(self.prefs['initialscript'], gtk.FALSE, gtk.FALSE, 5)
+		iniscbox.pack_start(gtk.Label(unicode(_('A first | is cursor position'), 'utf-8')),
+								 gtk.FALSE, gtk.FALSE, 5)
 
-		self.iniscbox = gtk.VBox()
-		self.iniscbox.show()
-		self.iniscbox.pack_start(self.prefs['initialscript'], gtk.FALSE, gtk.FALSE, 5)
-		self.iniscbox.pack_start(iniscl, gtk.FALSE, gtk.FALSE, 5)
-
-		self.iniscframe = gtk.Frame(unicode(_("Initial script")))
-		self.iniscframe.show()
-		self.iniscframe.set_border_width(5)
-		self.iniscframe.add(self.iniscbox)
+		iniscframe = gtk.Frame(unicode(_("Initial script")))
+		iniscframe.set_border_width(5)
+		iniscframe.add(iniscbox)
 
 # === Bring General and SSTP Frames together to General Tab === #
-		self.gentab = gtk.VBox()
-		self.gentab.show()
-		self.gentab.pack_start(self.genframe, gtk.FALSE, gtk.FALSE, 0)
-		self.gentab.pack_start(self.sendframe, gtk.FALSE, gtk.FALSE, 0)
-		self.gentab.pack_start(self.iniscframe, gtk.FALSE, gtk.FALSE, 0)
+		general_tab = gtk.VBox()
+		for item in [genframe, sendframe, iniscframe]:
+			general_tab.pack_start(item, gtk.FALSE, gtk.FALSE, 0)
+
+# === Create Font Tab === #
+		fonttable = gtk.Table(2, 3)
+		list = ['general font', 'script font']
+		for i in range(len(list)):
+			self.prefs[list[i]] = gtk.Entry()
+			fonttable.attach(gtk.Label(unicode(_(list[i]), 'utf-8')), 0, 1, i, i+1, gtk.FILL, gtk.FILL, 3, 3)
+			fonttable.attach(self.prefs[list[i]], 1, 2, i, i+1, gtk.FILL, gtk.FILL, 3, 3)
+			btn = get_icon_button(gtk.STOCK_SELECT_FONT, size=gtk.ICON_SIZE_BUTTON, relief=gtk.RELIEF_NORMAL)
+			btn.connect('clicked', self.open_fontselection, self.prefs[list[i]])
+			fonttable.attach(btn, 2, 3, i, i+1, gtk.FILL, gtk.FILL, 0, 3)
+
+		fontbox = gtk.VBox()
+		fontbox.pack_start(fonttable, gtk.FALSE, gtk.FALSE, 0)
+
+		fontframe = gtk.Frame(unicode(_("Font settings")))
+		fontframe.set_border_width(5)
+		fontframe.add(fontbox)
+
+		colortable = gtk.Table(6, 3)
+		list = ['script', 'sakura', 'kero', 'sync', 'error', 'URL']
+		for i in range(len(list)):
+			self.prefs[list[i]] = gtk.Entry()
+			colortable.attach(gtk.Label(unicode(_(list[i]), 'utf-8')), 0, 1, i, i+1, gtk.FILL, gtk.FILL, 3, 3)
+			colortable.attach(self.prefs[list[i]], 1, 2, i, i+1, gtk.FILL, gtk.FILL, 3, 3)
+			btn = get_icon_button(gtk.STOCK_SELECT_COLOR, size=gtk.ICON_SIZE_BUTTON, relief=gtk.RELIEF_NORMAL)
+			btn.connect('clicked', self.open_colorselection, self.prefs[list[i]])
+			colortable.attach(btn, 2, 3, i, i+1, gtk.FILL, gtk.FILL, 0, 3)
+
+		colorbox = gtk.VBox()
+		colorbox.pack_start(colortable, gtk.FALSE, gtk.FALSE, 0)
+
+		colorframe = gtk.Frame(unicode(_("Color settings")))
+		colorframe.set_border_width(5)
+		colorframe.add(colorbox)
+
+		fonttab = gtk.VBox()
+		fonttab.pack_start(fontframe)
+		fonttab.pack_start(colorframe)
 
 # === Create GViewer Tab == #
 		self.prefs['use_gviewer'] = gtk.CheckButton(unicode(_('Use GViewer'), 'utf-8'))
 		self.prefs['use_gviewer'].set_border_width(2)
 		self.prefs['use_gviewer'].connect('toggled', self.viewer_toggled)
-		self.prefs['use_gviewer'].show()
 
 		self.prefs['open_gviewer_when_play'] = gtk.CheckButton(unicode(_('Auto open GViewer when play script'), 'utf-8'))
 		self.prefs['open_gviewer_when_play'].set_border_width(2)
-		self.prefs['open_gviewer_when_play'].show()
 
 		adj = gtk.Adjustment(1.0, 0.0, 500.0, 1.0, 5.0, 0.0)
 		self.prefs['wait_1_char'] = gtk.SpinButton(adj, 0, 0)
-		self.prefs['wait_1_char'].show()
-		c1_label = gtk.Label(unicode(_('Wait for a character'), 'utf-8'))
-		c1_label.show()
-		ms_label1 = gtk.Label(unicode(_('milli seconds'), 'utf-8'))
-		ms_label1.show()
 
 		adj = gtk.Adjustment(1.0, 0.0, 500.0, 1.0, 5.0, 0.0)
 		self.prefs['wait_w1_tag'] = gtk.SpinButton(adj, 0, 0)
-		self.prefs['wait_w1_tag'].show()
-		w1_label = gtk.Label(unicode(_('Wait for \\w1'), 'utf-8'))
-		w1_label.show()
-		ms_label2 = gtk.Label(unicode(_('milli seconds'), 'utf-8'))
-		ms_label2.show()
 
 		wait_table = gtk.Table(2, 3)
-		wait_table.show()
-		wait_table.attach(c1_label,                  0, 1, 0, 1, gtk.FILL, gtk.FILL, 3, 3)
+		wait_table.attach(gtk.Label(unicode(_('Wait for a character'), 'utf-8')), 0, 1, 0, 1, gtk.FILL, gtk.FILL, 3, 3)
 		wait_table.attach(self.prefs['wait_1_char'], 1, 2, 0, 1, gtk.FILL, gtk.FILL, 3, 3)
-		wait_table.attach(ms_label1,                 2, 3, 0, 1, gtk.FILL, gtk.FILL, 3, 3)
-		wait_table.attach(w1_label,                  0, 1, 1, 2, gtk.FILL, gtk.FILL, 3, 3)
+		wait_table.attach(gtk.Label(unicode(_('milli seconds'), 'utf-8')), 2, 3, 0, 1, gtk.FILL, gtk.FILL, 3, 3)
+		wait_table.attach(gtk.Label(unicode(_('Wait for \\w1'), 'utf-8')), 0, 1, 1, 2, gtk.FILL, gtk.FILL, 3, 3)
 		wait_table.attach(self.prefs['wait_w1_tag'], 1, 2, 1, 2, gtk.FILL, gtk.FILL, 3, 3)
-		wait_table.attach(ms_label2,                 2, 3, 1, 2, gtk.FILL, gtk.FILL, 3, 3)
+		wait_table.attach(gtk.Label(unicode(_('milli seconds'), 'utf-8')), 2, 3, 1, 2, gtk.FILL, gtk.FILL, 3, 3)
 
 		viewbox = gtk.VBox()
-		viewbox.show()
 		viewbox.pack_start(self.prefs['use_gviewer'], gtk.FALSE, gtk.FALSE, 0)
 		viewbox.pack_start(self.prefs['open_gviewer_when_play'], gtk.FALSE, gtk.FALSE, 0)
 		viewbox.pack_start(wait_table, gtk.FALSE, gtk.FALSE, 0)
 
-		self.viewerframe = gtk.Frame(unicode(_('GViewer'), 'utf-8'))
-		self.viewerframe.show()
-		self.viewerframe.set_border_width(5)
-		self.viewerframe.add(viewbox)
+		viewerframe = gtk.Frame(unicode(_('GViewer'), 'utf-8'))
+		viewerframe.set_border_width(5)
+		viewerframe.add(viewbox)
 
-		self.viewertab = gtk.VBox()
-		self.viewertab.show()
-		self.viewertab.pack_start(self.viewerframe, gtk.FALSE, gtk.FALSE, 0)
+		viewer_tab = gtk.VBox()
+		viewer_tab.pack_start(viewerframe, gtk.FALSE, gtk.FALSE, 0)
 		self.viewer_toggled()
 
 # === Create Logging Frame == #
 		self.prefs['logging'] = gtk.CheckButton(unicode(_("Save `Current' log as XML when disconnect"), 'utf-8'))
 		self.prefs['logging'].set_border_width(2)
-		self.prefs['logging'].show()
 		self.prefs['logging'].connect('toggled', self.logging_toggled)
 
 		self.prefs['logging_current_tab_closed'] = gtk.CheckButton(unicode(_("Save log as XML when close `Current' tab"), 'utf-8'))
 		self.prefs['logging_current_tab_closed'].set_border_width(2)
-		self.prefs['logging_current_tab_closed'].show()
 		self.prefs['logging_current_tab_closed'].connect('toggled', self.logging_toggled)
 
+		self.prefs['logging_compress'] = gtk.CheckButton(unicode(_("GZIP Compress"), 'utf-8'))
+		self.prefs['logging_compress'].set_border_width(2)
+		self.prefs['logging_compress'].set_sensitive(gtk.FALSE)
+
 		self.prefs['logging_path'] = gtk.Entry()
-		self.prefs['logging_path'].show()
 		self.prefs['logging_path'].set_sensitive(gtk.FALSE)
-		ll = gtk.Label(unicode(_('Can use time format e.g. %H, %M, %S and etc.'), 'utf-8'))
-		ll.show()
 
 		lbox = gtk.VBox()
-		lbox.show()
 		lbox.pack_start(self.prefs['logging_path'], gtk.FALSE, gtk.FALSE, 3)
-		lbox.pack_start(ll, gtk.FALSE, gtk.FALSE, 3)
+		lbox.pack_start(gtk.Label(unicode(_('Can use time format e.g. %H, %M, %S and etc.'), 'utf-8')),
+						gtk.FALSE, gtk.FALSE, 3)
 
 		lframe = gtk.Frame(unicode(_('Filename'), 'utf-8'))
-		lframe.show()
 		lframe.set_shadow_type(gtk.SHADOW_ETCHED_OUT)
 		lframe.set_border_width(5)
 		lframe.add(lbox)
 
-		self.logbox1 = gtk.VBox()
-		self.logbox1.show()
-		self.logbox1.pack_start(self.prefs['logging'], gtk.FALSE, gtk.FALSE, 2)
-		self.logbox1.pack_start(self.prefs['logging_current_tab_closed'], gtk.FALSE, gtk.FALSE, 2)
-		self.logbox1.pack_start(lframe, gtk.FALSE, gtk.FALSE, 2)
+		logbox1 = gtk.VBox()
+		for item in [self.prefs['logging'], self.prefs['logging_current_tab_closed'],
+					 self.prefs['logging_compress'], lframe]:
+			logbox1.pack_start(item, gtk.FALSE, gtk.FALSE, 2)
 
-		self.logframe1 = gtk.Frame(unicode(_("Logs")))
-		self.logframe1.show()
-		self.logframe1.set_border_width(5)
-		self.logframe1.add(self.logbox1)
+		logframe1 = gtk.Frame(unicode(_("Logs")))
+		logframe1.set_border_width(5)
+		logframe1.add(logbox1)
 
 # === Create LogTab behavior Frame == #
-		self.logbox2 = gtk.VBox()
-		self.logbox2.show()
-
 		self.prefs['logtabfocus']  = gtk.CheckButton(unicode(_("Focus new page automatically"), 'utf-8'))
 		self.prefs['logtabfocus'].set_border_width(2)
-		self.prefs['logtabfocus'].show()
-		self.logbox2.pack_start(self.prefs['logtabfocus'], gtk.FALSE, gtk.FALSE, 2)
 
 		pagepos_table = gtk.Table(2, 2)
-		pagepos_table.show()
 		prev = None
 		list = [[
 			[POS_NEXT,  "To current tab's next"],
@@ -204,19 +204,19 @@ class PreferenceDialog:
 
 				self.prefs[pref]  = gtk.RadioButton(prev, unicode(_(description)))
 				self.prefs[pref].set_border_width(2)
-				self.prefs[pref].show()
 				pagepos_table.attach(self.prefs[pref], j, j+1, i, i+1, gtk.FILL, gtk.FILL, 3, 3)
 				prev = self.prefs[pref]
-		self.logbox2.pack_start(pagepos_table, gtk.FALSE, gtk.FALSE, 2)
 
-		self.logframe2 = gtk.Frame(unicode(_("When open new page...")))
-		self.logframe2.show()
-		self.logframe2.set_border_width(5)
-		self.logframe2.add(self.logbox2)
+		logbox2 = gtk.VBox()
+		logbox2.pack_start(self.prefs['logtabfocus'], gtk.FALSE, gtk.FALSE, 2)
+		logbox2.pack_start(pagepos_table, gtk.FALSE, gtk.FALSE, 2)
+
+		logframe2 = gtk.Frame(unicode(_("When open new page...")))
+		logframe2.set_border_width(5)
+		logframe2.add(logbox2)
 
 # === Create LogTab position Frame == #
 		tabpos_table = gtk.Table(4, 1)
-		tabpos_table.show()
 		prev = None
 		list = [['Top', 'Bottom', 'Left', 'Right']]
 		for i in range(len(list)):
@@ -234,55 +234,42 @@ class PreferenceDialog:
 					pref_name = "LOGTABPOS_%s" % gtk.POS_TOP
 
 				self.prefs[pref_name] = gtk.RadioButton(prev, unicode(_(label)))
-				self.prefs[pref_name].show()
 				tabpos_table.attach(self.prefs[pref_name], j, j+1, i, i+1, gtk.FILL, gtk.FILL, 3, 3)
 				prev = self.prefs[pref_name]
 
-		self.logframe3 = gtk.Frame(unicode(_("Tab position")))
-		self.logframe3.show()
-		self.logframe3.set_border_width(5)
-		self.logframe3.add(tabpos_table)
+		logframe3 = gtk.Frame(unicode(_("Tab position")))
+		logframe3.set_border_width(5)
+		logframe3.add(tabpos_table)
+
+# === Bring Logging, LogTab behavior, LogTab position frames together to Log Tab === #
+		log_tab = gtk.VBox()
+		log_tab.pack_start(logframe1, gtk.FALSE, gtk.FALSE, 0)
+		log_tab.pack_start(logframe2, gtk.FALSE, gtk.FALSE, 0)
+		log_tab.pack_start(logframe3, gtk.FALSE, gtk.FALSE, 0)
 
 # === Create Browser Frame == #
 		self.prefs['browser'] = gtk.Entry()
-		self.prefs['browser'].show()
 
-		self.brs_label = gtk.Label(unicode(_('Replace %s to URL'), 'utf-8'))
-		self.brs_label.show()
+		brsbox = gtk.VBox()
+		brsbox.pack_start(self.prefs['browser'], gtk.FALSE, gtk.FALSE, 5)
+		brsbox.pack_start(gtk.Label(unicode(_('Replace %s to URL'), 'utf-8')), gtk.TRUE, gtk.TRUE, 3)
 
-		self.logbox4 = gtk.VBox()
-		self.logbox4.show()
-		self.logbox4.pack_start(self.prefs['browser'], gtk.FALSE, gtk.FALSE, 5)
-		self.logbox4.pack_start(self.brs_label, gtk.TRUE, gtk.TRUE, 3)
-
-		self.logframe4 = gtk.Frame(unicode(_("Command to run browser")))
-		self.logframe4.show()
-		self.logframe4.set_border_width(5)
-		self.logframe4.add(self.logbox4)
-
-# === Bring Browser, Logging, LogTab behavior, LogTab position frames together to Log Tab === #
-		self.logtab = gtk.VBox()
-		self.logtab.show()
-		self.logtab.pack_start(self.logframe1, gtk.FALSE, gtk.FALSE, 0)
-		self.logtab.pack_start(self.logframe2, gtk.FALSE, gtk.FALSE, 0)
-		self.logtab.pack_start(self.logframe3, gtk.FALSE, gtk.FALSE, 0)
-		self.logtab.pack_start(self.logframe4, gtk.FALSE, gtk.FALSE, 0)
+		brsframe = gtk.Frame(unicode(_("Command to run browser")))
+		brsframe.set_border_width(5)
+		brsframe.add(brsbox)
 
 # === Create Download Frame === #
 		self.prefs['autodl'] = gtk.CheckButton(unicode(_("Auto download when receive script contained URL")))
 		self.prefs['autodl'].set_border_width(5)
-		self.prefs['autodl'].show()
 		self.prefs['autodl'].connect('toggled', self.download_toggled)
 
 		self.prefs['download_log'] = gtk.CheckButton(unicode(_("Logging history")))
 		self.prefs['download_log'].set_border_width(5)
-		self.prefs['download_log'].show()
 		self.prefs['download_log'].set_sensitive(gtk.FALSE)
 
 		# make table
 		rows = 4
 		ex_table = gtk.Table(7, rows)
-		ex_table.show()
 
 		keys = DL_SUFFIX_PATTERNS.keys()
 		keys.sort()
@@ -292,49 +279,27 @@ class PreferenceDialog:
 		for i in range(len(list)):
 			for j in range(len(list[i])):
 				self.prefs[list[i][j]] = gtk.CheckButton(list[i][j])
-				self.prefs[list[i][j]].show()
 				self.prefs[list[i][j]].set_sensitive(gtk.FALSE)
 				ex_table.attach(self.prefs[list[i][j]], j, j+1, i, i+1, gtk.FILL, gtk.FILL, 3, 3)
 
 		ex_frame = gtk.Frame(unicode(_('Supported file types'), 'utf-8'))
-		ex_frame.show()
 		ex_frame.set_shadow_type(gtk.SHADOW_ETCHED_OUT)
 		ex_frame.set_border_width(5)
 		ex_frame.add(ex_table)
 
-		self.dlbox = gtk.VBox()
-		self.dlbox.show()
-		self.dlbox.pack_start(self.prefs['autodl'], gtk.FALSE, gtk.FALSE, 0)
-		self.dlbox.pack_start(self.prefs['download_log'], gtk.FALSE, gtk.FALSE, 0)
-		self.dlbox.pack_start(ex_frame, gtk.FALSE, gtk.FALSE, 0)
+		dlbox = gtk.VBox()
+		dlbox.pack_start(self.prefs['autodl'], gtk.FALSE, gtk.FALSE, 0)
+		dlbox.pack_start(self.prefs['download_log'], gtk.FALSE, gtk.FALSE, 0)
+		dlbox.pack_start(ex_frame, gtk.FALSE, gtk.FALSE, 0)
 
-		self.dlframe = gtk.Frame(unicode(_("Download"), 'utf-8'))
-		self.dlframe.show()
-		self.dlframe.set_border_width(5)
-		self.dlframe.add(self.dlbox)
+		dlframe = gtk.Frame(unicode(_("Download"), 'utf-8'))
+		dlframe.set_border_width(5)
+		dlframe.add(dlbox)
 
-# === Create Color Tab === #
-		self.colortable = gtk.Table(6, 2)
-		self.colortable.show()
-
-		list = ['script', 'sakura', 'kero', 'sync', 'error', 'URL']
-		for i in range(len(list)):
-			entry = gtk.Entry()
-			entry.show()
-			label = gtk.Label(unicode(_(list[i]), 'utf-8'))
-			label.show()
-			self.prefs[list[i]] = entry
-			self.colortable.attach(label, 0, 1, i, i+1, gtk.FILL, gtk.FILL, 3, 3)
-			self.colortable.attach(entry, 1, 2, i, i+1, gtk.FILL, gtk.FILL, 3, 3)
-
-		self.colorbox = gtk.VBox()
-		self.colorbox.show()
-		self.colorbox.pack_start(self.colortable, gtk.FALSE, gtk.FALSE, 0)
-
-		self.colorframe = gtk.Frame(unicode(_("Color settings")))
-		self.colorframe.show()
-		self.colorframe.set_border_width(5)
-		self.colorframe.add(self.colorbox)
+# === Bring Browser, Download together to Log Tab === #
+		net_tab = gtk.VBox()
+		net_tab.pack_start(brsframe, gtk.FALSE, gtk.FALSE, 0)
+		net_tab.pack_start(dlframe, gtk.FALSE, gtk.FALSE, 0)
 
 # === Create LUID Tab === #
 		if luid_info:
@@ -345,7 +310,6 @@ class PreferenceDialog:
 			else:
 				self.luidinfolist = gtk.CList()
 			self.luidinfolist.column_titles_passive()
-			self.luidinfolist.show()
 			self.luidinfolist.set_column_auto_resize(1, gtk.TRUE)
 			self.luidinfolist.set_shadow_type(gtk.SHADOW_IN)
 			self.luidinfolist.set_selection_mode(gtk.SELECTION_BROWSE)
@@ -362,22 +326,16 @@ class PreferenceDialog:
 			self.luidinfolist.thaw()
 
 			self.luidinfosw = gtk.ScrolledWindow()
-			self.luidinfosw.show()
 			self.luidinfosw.set_size_request(300, 80)
 			self.luidinfosw.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
+			self.luidinfosw.set_border_width(5)
 			self.luidinfosw.add(self.luidinfolist)
 
-			self.luidinfof = gtk.Frame(unicode(_('General')))
-			self.luidinfof.set_border_width(5)
-			self.luidinfof.show()
-			self.luidinfof.add(self.luidinfosw)
-
 			if luid_data['table']:
 				self.luidlist = gtk.CList(len(luid_data['table'][0]), luid_data['table'][0])
 			else:
 				self.luidlist = gtk.CList()
 			self.luidlist.column_titles_passive()
-			self.luidlist.show()
 			self.luidlist.set_column_auto_resize(1, gtk.TRUE)
 			self.luidlist.set_shadow_type(gtk.SHADOW_IN)
 			self.luidlist.set_selection_mode(gtk.SELECTION_BROWSE)
@@ -394,40 +352,36 @@ class PreferenceDialog:
 			self.luidlist.thaw()
 
 			self.luidsw = gtk.ScrolledWindow()
-			self.luidsw.show()
 			self.luidsw.set_size_request(300, 100)
 			self.luidsw.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
+			self.luidsw.set_border_width(5)
 			self.luidsw.add(self.luidlist)
 
-			self.luidf = gtk.Frame(unicode(_('Details')))
-			self.luidf.set_border_width(5)
-			self.luidf.show()
-			self.luidf.add(self.luidsw)
+			luidbutton = gtk.Button(unicode(_('Update')))
+			luidbutton.connect('clicked', self.refresh_luid_info)
 
-			self.luidbutton = gtk.Button(unicode(_('Update')))
-			self.luidbutton.show()
-			self.luidbutton.connect('clicked', self.refresh_luid_info)
-
-			self.luidbox = gtk.VBox()
-			self.luidbox.show()
-			self.luidbox.pack_start(self.luidinfof, gtk.FALSE, gtk.FALSE, 0)
-			self.luidbox.pack_start(self.luidf, gtk.TRUE, gtk.TRUE, 0)
-			self.luidbox.pack_end(self.luidbutton, gtk.FALSE, gtk.FALSE, 3)
+			luidbox = gtk.VBox()
+			luidbox.pack_start(self.luidinfosw, gtk.FALSE, gtk.FALSE, 0)
+			luidbox.pack_start(self.luidsw, gtk.TRUE, gtk.TRUE, 0)
+			luidbox.pack_end(luidbutton, gtk.FALSE, gtk.FALSE, 3)
 
 # === Bring all Tabs together to Notebook === #
-		self.main_notebook = gtk.Notebook()
-		self.main_notebook.popup_enable()
-		self.main_notebook.set_scrollable(gtk.TRUE)
-		self.main_notebook.set_tab_pos(gtk.POS_TOP)
-		self.main_notebook.show()
+		main_notebook = gtk.Notebook()
+		main_notebook.popup_enable()
+		main_notebook.set_scrollable(gtk.TRUE)
+		main_notebook.set_tab_pos(gtk.POS_TOP)
+
+		for item in [
+			[general_tab, gtk.Label(unicode(_("General")))],
+			[log_tab,     gtk.Label(unicode(_("Logs")))],
+			[net_tab,     gtk.Label(unicode(_("Network")))],
+			[fonttab,     gtk.Label(unicode(_("Fonts")))],
+			[viewer_tab,  gtk.Label(unicode(_("GViewer")))],
+			]:
+			main_notebook.append_page(item[0], item[1])
 
-		self.main_notebook.append_page(self.gentab,     gtk.Label(unicode(_("General"))))
-		self.main_notebook.append_page(self.logtab,     gtk.Label(unicode(_("Logs"))))
-		self.main_notebook.append_page(self.viewertab,  gtk.Label(unicode(_("GViewer"))))
-		self.main_notebook.append_page(self.dlframe,    gtk.Label(unicode(_("Download"))))
-		self.main_notebook.append_page(self.colorframe, gtk.Label(unicode(_("Colors"))))
 		if luid_info is not None:
-			self.main_notebook.append_page(self.luidbox,    gtk.Label(unicode(_("LUID"))))
+			main_notebook.append_page(luidbox, gtk.Label(unicode(_("LUID"))))
 
 # === Bring all items together to Main Window Finally === #
 		self.window = gtk.Dialog(("%s: " % APP + unicode(_("Preferences"))), self.app.window,
@@ -436,16 +390,15 @@ class PreferenceDialog:
 								  gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT,
 								  gtk.STOCK_OK, gtk.RESPONSE_ACCEPT))
 		self.window.set_border_width(5)
+		self.window.vbox.pack_start(main_notebook, gtk.TRUE, gtk.TRUE, 0)
 		self.window.connect("destroy", self.close)
-		self.window.set_title("%s: " % APP + unicode(_("Preferences")))
-		self.window.vbox.pack_start(self.main_notebook, gtk.TRUE, gtk.TRUE, 0)
+		self.window.show_all()
 
 # === Initialization of PreferenceDialog === #
 		self.prefmanager.load_database()
 		self.set_prefs()
 
 # === Start mainloop of Dialog === #
-		self.window.show()
 		while True:
 			response = self.window.run()
 
@@ -462,6 +415,28 @@ class PreferenceDialog:
 				self.close()
 				break
 
+	def open_fontselection(self, widget=None, entry=None):
+		fontsel = gtk.FontSelectionDialog(unicode(_('Chose font...'), 'utf-8'))
+		fontsel.show()
+		fontsel.set_font_name(entry.get_text())
+		res = fontsel.run()
+		fontsel.hide()
+		if res == gtk.RESPONSE_OK:
+			entry.set_text(fontsel.get_font_name())
+		fontsel.destroy()
+
+	def open_colorselection(self, widget=None, entry=None):
+		colorsel = gtk.ColorSelectionDialog(unicode(_('Chose color...'), 'utf-8'))
+		colorsel.show()
+		colorsel.colorsel.set_current_color(gtk.gdk.color_parse(entry.get_text()))
+		res = colorsel.run()
+		colorsel.hide()
+		if res == gtk.RESPONSE_OK:
+			color = colorsel.colorsel.get_current_color()
+			color_str = "#%04x%04x%04x" % (color.red, color.green, color.blue)
+			entry.set_text(color_str)
+		colorsel.destroy()
+
 	def refresh_luid_info(self, widget=None, data=None):
 		luid_data = self.luid_info.get_all(True)
 
@@ -503,8 +478,9 @@ class PreferenceDialog:
 		# CheckButtons
 		for name in ['auto_open_log', 'auto_connect', 'auto_join', 'autodl',
 					 'forward', 'accept_all', 'forward_listed', 'auto_clear',
-					 'logging', 'logging_current_tab_closed', 'open_gviewer_when_play',
-					 'logtabfocus', 'download_log', 'sent_log', 'use_gviewer'] + DL_SUFFIX_PATTERNS.keys():
+					 'logging', 'logging_current_tab_closed', 'logging_compress',
+					 'open_gviewer_when_play', 'logtabfocus', 'download_log',
+					 'sent_log', 'use_gviewer'] + DL_SUFFIX_PATTERNS.keys():
 			prefs[name] = self.prefs[name].get_active()
 
 		# SpinButtons
@@ -514,7 +490,8 @@ class PreferenceDialog:
 		# Entries
 		for name in ['browser', 'script', 'sakura',
 					 'kero', 'sync', 'error', 'URL',
-					 'initialscript', 'logging_path']:
+					 'initialscript', 'logging_path',
+					 'general font', 'script font']:
 			prefs[name] = self.prefs[name].get_text()
 
 		# RadioButtons
@@ -537,7 +514,8 @@ class PreferenceDialog:
 				# Entries
 				if key in ['browser', 'script', 'sakura',
 						   'kero', 'sync', 'error', 'URL',
-						   'initialscript', 'logging_path']:
+						   'initialscript', 'logging_path',
+						   'general font', 'script font']:
 					self.prefs[key].set_text(self.prefmanager.rc[key])
 
 				# SpinButtons
@@ -581,8 +559,10 @@ class PreferenceDialog:
 
 		if not logging_state and not logcurr_state:
 			self.prefs['logging_path'].set_sensitive(gtk.FALSE)
+			self.prefs['logging_compress'].set_sensitive(gtk.FALSE)
 		else:
 			self.prefs['logging_path'].set_sensitive(gtk.TRUE)
+			self.prefs['logging_compress'].set_sensitive(gtk.TRUE)
 
 	def viewer_toggled(self, widget=None, data=None):
 		viewer_state = self.prefs['use_gviewer'].get_active()
@@ -618,10 +598,13 @@ class PreferenceManager:
 					 ['wait_w1_tag', 50],
 					 ['logging', False],
 					 ['logging_current_tab_closed', False],
+					 ['logging_compress', False],
 					 ['logging_path', os.path.normpath(open_bottlecase() + '/autolog/%Y%m%d/%H-%M-%S.xml')],
 					 ['logtabfocus', True],
 					 ['logpagepos', POS_NEXT],
 					 ['logtabpos', gtk.POS_TOP],
+					 ['general font', 'Sans 10'],
+					 ['script font', 'Monospace 10'],
 					 ['browser', "mozilla -remote 'openFile(%s,new-tab)'"],
 					 ['script', "dark green"],
 					 ['sakura', "black"],
