@@ -10,7 +10,7 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: textmanager.py,v 1.32 2004/08/20 06:09:51 atzm Exp $
+# $Id: textmanager.py,v 1.33 2004/09/15 03:40:31 atzm Exp $
 #
 
 import os
@@ -22,7 +22,7 @@ from types import *
 from common import *
 
 class TextManager(gtk.TextView):
-	FONT_SCRIPT = 'Monospace'
+	#FONT_SCRIPT = 'Monospace'
 
 	def __init__(self, app, prefs, parser=BottleParser('loose')):
 		gtk.TextView.__init__(self)
@@ -46,7 +46,8 @@ class TextManager(gtk.TextView):
 
 		url_tag = self.textbuffer.create_tag('URL')
 		self.font_tag = self.textbuffer.create_tag('font')
-		self.default_font = self.font_tag.get_property('font')
+		self.script_font = self.prefs.get('script font') #self.font_tag.get_property('font')
+		self.general_font = self.prefs.get('general font') #self.font_tag.get_property('font')
 
 		# some connection
 		self.p_flag = False
@@ -74,6 +75,11 @@ class TextManager(gtk.TextView):
 
 		tag_table.lookup('overURL').set_property('background', over_color)
 
+	def font_changed(self, genfont, scfont):
+		self.general_font = genfont
+		self.script_font = scfont
+		self.set_style(self.view_style)
+
 	def receive_event(self, texttag, widget, event, iter):
 		buf = iter.get_buffer()
 		end = iter.copy()
@@ -301,15 +307,15 @@ class TextManager(gtk.TextView):
 
 	def set_style_talk(self):
 		self.view_style = STYLE_TALK
-		self.font_tag.set_property('font', self.default_font)
+		self.font_tag.set_property('font', self.general_font)
 
 	def set_style_script(self):
 		self.view_style = STYLE_SCRIPT
-		self.font_tag.set_property('font', self.FONT_SCRIPT)
+		self.font_tag.set_property('font', self.script_font)
 
 	def set_style_script_with_linefeed(self):
 		self.view_style = STYLE_SCRIPT_WITH_LINEFEED
-		self.font_tag.set_property('font', self.FONT_SCRIPT)
+		self.font_tag.set_property('font', self.script_font)
 
 	def set_style(self, style):
 		if type(style) is not IntType:
