@@ -12,7 +12,7 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: ghost.py,v 1.8 2004/08/27 18:14:03 tkawa Exp $
+# $Id: ghost.py,v 1.11 2004/09/10 16:07:41 atzm Exp $
 #
 
 import gtk
@@ -30,6 +30,7 @@ class Ghost:
 
 		self.svg_dir     = svg_dir
 		self.surface_dic = {}
+		self.reverse_dic = {}
 
 		self.sakura      = None
 		self.unyu        = None
@@ -49,7 +50,7 @@ class Ghost:
 		last_splite = 0
 
 		if self.debug:
-			print '-' * 20
+			sys.stderr.write('%s\n' % ('-' * 20))
 		self.debugprint('Ghost def text', svg_txt)
 
 		try:
@@ -202,18 +203,26 @@ class Ghost:
 
 		#print self.surface_dic
 
+		image_path = os.path.join(self.svg_dir, self.surfacefile)
+		try:
+			self.ghost_pixbuf = gtk.gdk.pixbuf_new_from_file(image_path)
+		except:
+			self.debugprint("can't open file", image_path)
+			self.ghost_pixbuf = None
+
 	def set_debug(self, flag):
 		self.debug = bool(flag)
 
 	def debugprint(self, desc, text):
 		if self.debug:
-			print "%-14s: %s" % (desc, text)
+			sys.stderr.write("%-15s: %s\n" % (desc, text.encode('euc-jp')))
 
 	EXPAND_QUOTE_REGEX = re.compile('"(.*)"')
 	def expand_quote(self, text):
-		m = self.EXPAND_QUOTE_REGEX.match(text)
-		if m is not None:
-			text = m.group(1)
+		try:
+			text = self.EXPAND_QUOTE_REGEX.match(text).group(1)
+		except AttributeError:
+			pass
 		return text	
 
 	def __str__(self):
@@ -292,21 +301,14 @@ class Ghost:
 				else:
 					id = 0
 
-		path = os.path.join(self.svg_dir, self.surfacefile)
-		try:
-			current_ghost_pixbuf = gtk.gdk.pixbuf_new_from_file(path)
-		except:
-			self.debugprint("can't open file", path)
+		if self.ghost_pixbuf is None:
 			return None
-## 			self.current_ghost_pixbuf = gtk.gdk.pixbuf_new_from_file('svg.png')
-## 			a = 0
-## 			b = 0
 		else:
 			if id == -1:
 				area = gtk.gdk.pixbuf_new_from_xpm_data(XPM_VANISH)
 			else:
-				svg_width  = current_ghost_pixbuf.get_width()
-				svg_height = current_ghost_pixbuf.get_height()
+				svg_width  = self.ghost_pixbuf.get_width()
+				svg_height = self.ghost_pixbuf.get_height()
 
 				x = svg_width / SIZE_SURFACE_H
 				y = svg_height / SIZE_SURFACE_V
@@ -314,7 +316,12 @@ class Ghost:
 				b = id / x
 
 				area = gtk.gdk.Pixbuf(gtk.gdk.COLORSPACE_RGB, gtk.TRUE, 8, 48, 64)
-				current_ghost_pixbuf.copy_area(SIZE_SURFACE_H * a, SIZE_SURFACE_V * b,
-											   SIZE_SURFACE_H, SIZE_SURFACE_V, area, 0, 0)
+				self.ghost_pixbuf.copy_area(SIZE_SURFACE_H * a, SIZE_SURFACE_V * b,
+											SIZE_SURFACE_H, SIZE_SURFACE_V, area, 0, 0)
 
 		return area
+
+	def set_reverse_dic(self):
+		for i in self.surface_dic.keys():
+			if not self.reverse_dic.has_key(i):
+				self.reverse_dic[self.surface_dic[i]] = i
