@@ -11,7 +11,7 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: ghostmanager.py,v 1.8 2004/07/27 19:55:45 atzm Exp $
+# $Id: ghostmanager.py,v 1.11 2004/09/10 16:07:41 atzm Exp $
 #
 
 import os
@@ -26,9 +26,9 @@ class GhostManager:
 	def __init__(self, textfile='ghost.txt', debug=DEBUG):
 		self.ghost_dic = {}
 		self.fmo_ghost_list = []
+		self.debug = debug
 
 		self.generate_dictionary(textfile)
-		self.debug = debug
 
 	def set_debug(self, flag):
 		self.debug = bool(flag)
@@ -44,8 +44,8 @@ class GhostManager:
 			return Ghost(self.ghost_dic[ifghost], svg_dir)
 		except KeyError:
 			if self.debug:
-				print '-' * 20
-				print 'no such ghost: %s' % ifghost
+				sys.stderr.write('%s\n' % ('-' * 20))
+				sys.stderr.write('no such ghost: %s\n' % ifghost)
 			return None
 
 	def nominate_ghost_txt(self, svg_txt, svg_dir='Ghost'):
@@ -53,8 +53,8 @@ class GhostManager:
 			return Ghost(svg_txt, svg_dir)
 		except KeyError:
 			if self.debug:
-				print '-' * 20
-				print 'no such svg_txt: %s' % svg_txt
+				sys.stderr.write('%s\n' % ('-' * 20))
+				sys.stderr.write('no such svg_txt: %s\n' % svg_txt)
 			return None
 
 	def get_fmo_ghosts(self):
@@ -98,6 +98,6 @@ class GhostManager:
 			self.ghost_dic[ghostname] = path
 
 			if fmo == "FMO":
-				if ghostname in [NAME_SAKURA_KAWAKAMI, NAME_SAKURA_KUROI]:
-					ghostname = NAME_SAKURA
-				self.fmo_ghost_list.append(ghostname)
+				ghost = self.nominate_ghost_txt(path, os.path.dirname(path))
+				name  = ghost.get_sakura()
+				self.fmo_ghost_list.append(name)
